@@ -9,6 +9,7 @@ import base64
 import subprocess
 import re
 from getpass import getpass
+import urllib
 
 import requests
 from requests.auth import HTTPBasicAuth
@@ -19,6 +20,7 @@ from cryptography.hazmat.primitives.asymmetric import padding
 from cryptography.hazmat.backends import default_backend
 from cryptography.hazmat.primitives import serialization
 
+from .common import red
 
 def encrypt_variable(variable, build_repo, *, public_key=None, is_private=False, **login_kwargs):
     """
@@ -129,6 +131,8 @@ def GitHub_login(*, username=None, password=None, OTP=None, headers=None):
     if r.status_code == 401:
         two_factor = r.headers.get('X-GitHub-OTP')
         if two_factor:
+            if OTP:
+                print(red("Invalid authentication code"))
             auth_header = base64.urlsafe_b64encode(bytes(username + ':' + password, 'utf8')).decode()
             login_kwargs = {'auth': None, 'headers': {'Authorization': 'Basic {}'.format(auth_header)}}
             try:
@@ -234,6 +238,7 @@ def check_repo_exists(deploy_repo, service='github', *, auth=None, headers=None)
 
     Returns whether or not the repo is private
     """
+    headers = headers or {}
     if deploy_repo.count("/") != 1:
         raise RuntimeError('"{deploy_repo}" should be in the form username/repo'.format(deploy_repo=deploy_repo))
 
@@ -241,7 +246,8 @@ def check_repo_exists(deploy_repo, service='github', *, auth=None, headers=None)
     if service == 'github':
         REPO_URL = 'https://api.github.com/repos/{user}/{repo}'
     elif service == 'travis':
-        REPO_URL = 'https://api.travis-ci.org/{user}/{repo}'
+        REPO_URL = 'https://api.travis-ci.org/repo/{user}%2F{repo}'
+        headers['Travis-API-Version'] = '3'
     else:
         raise RuntimeError('Invalid service specified for repo check (neither "travis" nor "github")')
 
@@ -250,7 +256,8 @@ def check_repo_exists(deploy_repo, service='github', *, auth=None, headers=None)
         wiki = True
         repo = repo[:-5]
 
-    r = requests.get(REPO_URL.format(user=user, repo=repo), auth=auth, headers=headers)
+    r = requests.get(REPO_URL.format(user=urllib.parse.quote(user),
+        repo=urllib.parse.quote(repo)), auth=auth, headers=headers)
 
     if r.status_code == requests.codes.not_found:
         raise RuntimeError('"{user}/{repo}" not found on {service}'.format(user=user,
@@ -259,7 +266,7 @@ def check_repo_exists(deploy_repo, service='github', *, auth=None, headers=None)
 
     r.raise_for_status()
     private = r.json().get('private', False)
-    
+
     if wiki and not private:
         # private wiki needs authentication, so skip check for existence
         p = subprocess.run(['git', 'ls-remote', '-h', 'https://github.com/{user}/{repo}.wiki'.format(
